@@ -15,7 +15,7 @@ def main() :
 
   if len(sys.argv)<2 : 
     print("This is a script to create an example Python file for PIDGen2 resampling.")
-    print("Usage: create_example examplefilename.py")
+    print("Usage: pidgen2.create_example examplefilename.py")
   else : 
     outputname = sys.argv[1]
     inputname = os.path.dirname(os.path.abspath(__file__)) + "/example.py"
