@@ -16,7 +16,7 @@ from .resampling import get_samples
 def main() : 
 
   samples = get_samples().keys()
-  for s in samples : 
+  for s in sorted(samples) : 
     print(f"{s}")
 
 if __name__ == "__main__" : 
