@@ -16,7 +16,7 @@ from .resampling import get_variables
 def main() : 
 
   variables = get_variables().keys()
-  for v in variables : 
+  for v in sorted(variables) : 
     print(f"{v}")
 
 if __name__ == "__main__" : 
