@@ -102,6 +102,12 @@ def resample(
   if not isinstance(kernels, (list, tuple)) : 
     kernel_list = [ kernels ]
 
+  # Evaluate scaling list if it is a string
+  if isinstance(scale, str) : 
+    scale_list = eval(scale)
+  else : 
+    scale_list = scale
+
   output_arrays = []
   output_branches = []
 
@@ -144,7 +150,7 @@ def resample(
 
       onp.random.seed(resampling_seed)
 
-      data = data_transform(input_data, config, scale = [ float(i) for i in scale.split(":")] if scale else None )
+      data = data_transform(input_data, config, scale = scale_list )
       pid_arr, calib_stat = resample_data(data, config, vardef, template, verbose = verbose)
 
       if not (nan is None) : 
@@ -172,7 +178,7 @@ def resample(
 
 def main() : 
 
-  parser = argparse.ArgumentParser(description = "PIDGen resampling script", 
+  parser = argparse.ArgumentParser(description = "PIDGen2 resampling script", 
                                    formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
   parser.add_argument('--resampling_seed', type=int, default = 1, 
@@ -224,7 +230,7 @@ def main() :
   parser.add_argument('--nan', type=float, default = -1000., 
                       help="Numerical value to replace NaN in resampled PID (when calibration data is missing)")
   parser.add_argument('--scale', type=str, default = None, 
-                      help="List of scale factors for input data e.g. '1:1:1.15' for 15%% upscaling of multiplicity")
+                      help="List of scale factors for input data e.g. --scale='1,1,1.15' for 15%% upscaling of multiplicity")
 
   args = parser.parse_args()
 
